Connection class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
connect(
) → Future< void> -
dispatchResponse(
int code, BufferReader reader) → void -
emit(
dynamic event, [dynamic data]) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
off(
dynamic event, dynamic callback(dynamic)) → void -
inherited
-
on(
dynamic event, dynamic callback(dynamic)) → void -
inherited
-
once(
dynamic event, dynamic callback(dynamic)) → void -
inherited
-
onConnected(
) → void -
onDisconnected(
) → void -
onFrameReceived(
Uint8List frame) → void -
sendToRadioFrame(
Uint8List data) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
waitForResponse(
dynamic event, {Duration? timeout}) → Future
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited